==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/bs/hebrew.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "prošli utorak",
	"field-year": "godina",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-minute": "minuta",
	"field-tue-narrow-relative+0": "ovaj uto.",
	"field-tue-narrow-relative+1": "sljedeći uto.",
	"field-thu-short-relative+0": "ovaj čet.",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "sljedeći čet.",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-day-relative+2": "prekosutra",
	"field-wed-narrow-relative+-1": "prošla sri.",
	"field-year-narrow": "g.",
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"field-second-short": "sek.",
	"dayPeriods-format-narrow-am": "prijepodne",
	"dateFormatItem-MMMd": "d. MMM",
	"dayPeriods-format-abbr-am": "prijepodne",
	"field-week-relative+0": "ove sedmice",
	"field-month-relative+0": "ovaj mjesec",
	"field-week-relative+1": "sljedeće sedmice",
	"field-month-relative+1": "sljedeći mjesec",
	"field-sun-narrow-relative+0": "ova ned.",
	"field-mon-short-relative+0": "ovaj pon.",
	"field-sun-narrow-relative+1": "sljedeća ned.",
	"field-mon-short-relative+1": "sljedeći pon",
	"field-second-relative+0": "sada",
	"dayPeriods-standAlone-abbr-pm": "popodne",
	"field-month-short": "mj.",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-yyyyMd": "d.M.y. G",
	"field-day": "dan",
	"field-year-relative+-1": "prošle godine",
	"dayPeriods-format-wide-am": "prijepodne",
	"field-sat-short-relative+-1": "prošla sub.",
	"field-hour-relative+0": "ovaj sat",
	"dateFormatItem-yyyyMEd": "E, d.M.y. G",
	"field-wed-relative+-1": "prošla srijeda",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "prošla sub.",
	"field-second": "sekunda",
	"days-standAlone-narrow": [
		"n",
		"p",
		"u",
		"s",
		"č",
		"p",
		"s"
	],
	"dayPeriods-standAlone-wide-pm": "popodne",
	"dateFormat-long": "dd. MMMM y. G",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-quarter": "kvartal",
	"field-week-short": "sed.",
	"quarters-standAlone-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"days-format-narrow": [
		"N",
		"P",
		"U",
		"S",
		"Č",
		"P",
		"S"
	],
	"field-tue-short-relative+0": "ovaj uto.",
	"field-tue-short-relative+1": "sljedeći uto.",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-month": "mjesec",
	"field-day-narrow": "dan",
	"field-minute-short": "min.",
	"field-dayperiod": "prijepodne/poslijepodne",
	"field-sat-short-relative+0": "ova sub.",
	"field-sat-short-relative+1": "sljedeća sub.",
	"dayPeriods-format-narrow-pm": "popodne",
	"dateFormat-medium": "dd.MM.y. G",
	"dateFormatItem-yyyyMMMM": "LLLL y. G",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dayPeriods-format-abbr-pm": "popodne",
	"dateFormatItem-yyyyM": "MM/y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-year-short": "god.",
	"field-quarter-relative+-1": "posljednji kvartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"dayPeriods-standAlone-narrow-am": "prijepodne",
	"days-format-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"dayPeriods-format-wide-pm": "popodne",
	"field-sat-relative+-1": "prošla subota",
	"dateTimeFormat-long": "{1} 'u' {0}",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "sat",
	"dateFormat-full": "EEEE, dd. MMMM y. G",
	"field-month-relative+-1": "prošli mjesec",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "ova sub.",
	"field-fri-relative+0": "ovaj petak",
	"field-sat-narrow-relative+1": "sljedeća sub.",
	"field-fri-relative+1": "sljedeći petak",
	"field-sun-short-relative+0": "ova ned.",
	"field-sun-short-relative+1": "sljedeća ned.",
	"field-week-relative+-1": "prošle sedmice",
	"field-quarter-relative+0": "ovaj kvartal",
	"field-minute-relative+0": "ova minuta",
	"field-quarter-relative+1": "sljedeći kvartal",
	"field-wed-short-relative+-1": "prošla sri.",
	"dateFormat-short": "dd.MM.y. GGGGG",
	"field-thu-short-relative+-1": "prošli čet.",
	"days-standAlone-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"field-mon-narrow-relative+-1": "prošli pon.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "prošli čet.",
	"field-tue-narrow-relative+-1": "prošli uto.",
	"dateFormatItem-yyyy": "y. G",
	"dayPeriods-standAlone-narrow-pm": "popodne",
	"field-wed-short-relative+0": "ova sri.",
	"field-wed-short-relative+1": "sljedeća sri.",
	"field-sun-relative+-1": "prošla nedjelja",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateTimeFormat-full": "{1} 'u' {0}",
	"dateFormatItem-hm": "hh:mm a",
	"field-weekday": "dan u sedmici",
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"dateFormatItem-MEd": "E, d.M.",
	"dateFormatItem-y": "y. G",
	"field-thu-narrow-relative+0": "ovaj čet.",
	"field-thu-narrow-relative+1": "sljedeći čet.",
	"field-sun-narrow-relative+-1": "prošla ned.",
	"field-mon-short-relative+-1": "prošli pon.",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-fri-short-relative+-1": "prošli pet.",
	"field-thu-relative+-1": "prošli četvrtak",
	"field-week": "sedmica",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"quarters-format-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"dateFormatItem-Ed": "E, d.",
	"field-wed-narrow-relative+0": "ova sri.",
	"field-wed-narrow-relative+1": "sljedeća sri.",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"field-fri-short-relative+0": "ovaj pet.",
	"field-fri-short-relative+1": "sljedeći pet.",
	"days-standAlone-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"field-hour-short": "h",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-month-narrow": "mj.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "prošli pet.",
	"field-year-relative+0": "ove godine",
	"field-year-relative+1": "sljedeće godine",
	"field-fri-relative+-1": "prošli petak",
	"field-tue-short-relative+-1": "prošli uto.",
	"field-minute-narrow": "min.",
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"field-mon-narrow-relative+0": "ovaj pon.",
	"field-mon-narrow-relative+1": "sljedeći pon",
	"field-zone": "vremenska zona",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "prošla ned.",
	"field-day-relative+-1": "jučer",
	"dayPeriods-standAlone-abbr-am": "prijepodne",
	"field-day-relative+-2": "prekjučer",
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"dateFormatItem-Gy": "y. G",
	"field-day-short": "dan",
	"field-week-narrow": "sed.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "ovaj pet.",
	"field-fri-narrow-relative+1": "sljedeći pet.",
	"dayPeriods-standAlone-wide-am": "prijepodne"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/bs/hebrew.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "prošli utorak",
	"field-year": "godina",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-minute": "minuta",
	"field-tue-narrow-relative+0": "ovaj uto.",
	"field-tue-narrow-relative+1": "sljedeći uto.",
	"field-thu-short-relative+0": "ovaj čet.",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "sljedeći čet.",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-day-relative+2": "prekosutra",
	"field-wed-narrow-relative+-1": "prošla sri.",
	"field-year-narrow": "g.",
	"field-era-short": "era",
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"field-weekdayOfMonth": "dan u mjesecu",
	"field-second-short": "sek.",
	"dayPeriods-format-narrow-am": "prijepodne",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "d. u mj.",
	"field-week-relative+0": "ove sedmice",
	"field-month-relative+0": "ovaj mjesec",
	"field-week-relative+1": "sljedeće sedmice",
	"field-month-relative+1": "sljedeći mjesec",
	"field-sun-narrow-relative+0": "ova ned.",
	"field-mon-short-relative+0": "ovaj pon.",
	"field-sun-narrow-relative+1": "sljedeća ned.",
	"field-mon-short-relative+1": "sljedeći pon",
	"field-second-relative+0": "sada",
	"field-weekOfMonth": "sedmica u mjesecu",
	"field-month-short": "mj.",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-yyyyMd": "d.M.y. G",
	"field-day": "dan",
	"field-dayOfYear-short": "dan u god.",
	"field-year-relative+-1": "prošle godine",
	"dayPeriods-format-wide-am": "prijepodne",
	"field-sat-short-relative+-1": "prošla sub.",
	"field-hour-relative+0": "ovaj sat",
	"dateFormatItem-yyyyMEd": "E, d.M.y. G",
	"field-wed-relative+-1": "prošla srijeda",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "prošla sub.",
	"field-second": "sekunda",
	"days-standAlone-narrow": [
		"n",
		"p",
		"u",
		"s",
		"č",
		"p",
		"s"
	],
	"dayPeriods-standAlone-wide-pm": "popodne",
	"dateFormat-long": "dd. MMMM y. G",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-quarter": "kvartal",
	"field-week-short": "sed.",
	"quarters-standAlone-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"days-format-narrow": [
		"N",
		"P",
		"U",
		"S",
		"Č",
		"P",
		"S"
	],
	"field-tue-short-relative+0": "ovaj uto.",
	"field-tue-short-relative+1": "sljedeći uto.",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-month": "mjesec",
	"field-day-narrow": "dan",
	"field-minute-short": "min.",
	"field-dayperiod": "prijepodne/poslijepodne",
	"field-sat-short-relative+0": "ova sub.",
	"field-sat-short-relative+1": "sljedeća sub.",
	"dayPeriods-format-narrow-pm": "popodne",
	"dateFormat-medium": "dd.MM.y. G",
	"dateFormatItem-yyyyMMMM": "LLLL y. G",
	"eraAbbr": [
		"AM"
	],
	"quarters-standAlone-abbr": [
		"KV1",
		"KV2",
		"KV3",
		"KV4"
	],
	"dateFormatItem-yyyyM": "MM/y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-year-short": "god.",
	"field-quarter-relative+-1": "posljednji kvartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"field-dayperiod-narrow": "prijepodne/poslijepodne",
	"dayPeriods-standAlone-narrow-am": "prijepodne",
	"days-format-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"dayPeriods-format-wide-pm": "popodne",
	"field-dayOfYear": "dan u godini",
	"field-sat-relative+-1": "prošla subota",
	"dateTimeFormat-long": "{1} 'u' {0}",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "sat",
	"dateFormat-full": "EEEE, dd. MMMM y. G",
	"field-month-relative+-1": "prošli mjesec",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "ova sub.",
	"field-fri-relative+0": "ovaj petak",
	"field-sat-narrow-relative+1": "sljedeća sub.",
	"field-fri-relative+1": "sljedeći petak",
	"field-sun-short-relative+0": "ova ned.",
	"field-sun-short-relative+1": "sljedeća ned.",
	"field-week-relative+-1": "prošle sedmice",
	"field-quarter-relative+0": "ovaj kvartal",
	"field-minute-relative+0": "ova minuta",
	"field-quarter-relative+1": "sljedeći kvartal",
	"field-wed-short-relative+-1": "prošla sri.",
	"dateFormat-short": "dd.MM.y. GGGGG",
	"field-thu-short-relative+-1": "prošli čet.",
	"days-standAlone-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"field-mon-narrow-relative+-1": "prošli pon.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "prošli čet.",
	"field-tue-narrow-relative+-1": "prošli uto.",
	"dateFormatItem-H": "H",
	"field-weekOfMonth-short": "sed. u mj.",
	"dateFormatItem-yyyy": "y. G",
	"dayPeriods-standAlone-narrow-pm": "popodne",
	"field-wed-short-relative+0": "ova sri.",
	"field-wed-short-relative+1": "sljedeća sri.",
	"field-sun-relative+-1": "prošla nedjelja",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateTimeFormat-full": "{1} 'u' {0}",
	"dateFormatItem-hm": "hh:mm a",
	"field-weekday": "dan u sedmici",
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-dayOfYear-narrow": "dan u g.",
	"field-weekdayOfMonth-short": "dan u mj.",
	"dateFormatItem-MEd": "E, d.M.",
	"field-zone-narrow": "zona",
	"dateFormatItem-y": "y. G",
	"field-thu-narrow-relative+0": "ovaj čet.",
	"field-thu-narrow-relative+1": "sljedeći čet.",
	"field-sun-narrow-relative+-1": "prošla ned.",
	"field-mon-short-relative+-1": "prošli pon.",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-fri-short-relative+-1": "prošli pet.",
	"field-thu-relative+-1": "prošli četvrtak",
	"field-week": "sedmica",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"quarters-format-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"dateFormatItem-Ed": "E, d.",
	"field-wed-narrow-relative+0": "ova sri.",
	"field-wed-narrow-relative+1": "sljedeća sri.",
	"field-dayperiod-short": "prijepodne/poslijepodne",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"field-fri-short-relative+0": "ovaj pet.",
	"field-fri-short-relative+1": "sljedeći pet.",
	"days-standAlone-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"field-zone-short": "zona",
	"field-hour-short": "h",
	"quarters-format-abbr": [
		"KV1",
		"KV2",
		"KV3",
		"KV4"
	],
	"field-month-narrow": "mj.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "prošli pet.",
	"field-year-relative+0": "ove godine",
	"field-year-relative+1": "sljedeće godine",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "prošli petak",
	"field-tue-short-relative+-1": "prošli uto.",
	"field-minute-narrow": "min.",
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"field-mon-narrow-relative+0": "ovaj pon.",
	"field-mon-narrow-relative+1": "sljedeći pon.",
	"field-zone": "vremenska zona",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-weekOfMonth-narrow": "s. u mj.",
	"field-weekday-narrow": "dan u sed.",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "prošla ned.",
	"field-day-relative+-1": "jučer",
	"field-day-relative+-2": "prekjučer",
	"field-weekday-short": "dan u sed.",
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"dateFormatItem-Gy": "y. G",
	"field-day-short": "dan",
	"field-week-narrow": "sed.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "ovaj pet.",
	"field-fri-narrow-relative+1": "sljedeći pet.",
	"dayPeriods-standAlone-wide-am": "prijepodne"
}
//end v1.x content
);
